# nputop
An interactive ASCEND-NPU process viewer and beyond, the one-stop solution for NPU process management. 

<p align="center">
  <img width="100%" src="./docs/home.png" alt="Monitor">
  <br/>
  Monitor mode of <code>nvitop</code>.
  <br/>
</p>


### Quick Start

Install nputop by using pip as follows. 

```bash
pip install nputop
```

To start a instance of nputop, run the following command:

```bash
$ nputop
```
